@@ -8,16 +8,17 @@ def set_weight(ver, val):
     ver = val
 
 def mk_class_get(all_classes={}, kerasy_abst_class=[], genre=""):
-    def get(identifier):
+    def get(identifier, **kwargs):
         f"""
         Retrieves a Kerasy {genre.capitalize()} instance.
         @params identifier : {genre.capitalize()} identifier, string name of a {genre}, or
                              a Kerasy {genre.capitalize()} instance.
+        @params kwargs     : parametes for class initialization.
         @return {genre:<11}: A Kerasy {genre.capitalize()} instance.
         """
         if isinstance(identifier, str):
             handleKeyError(lst=list(all_classes.keys()), identifier=identifier)
-            instance = all_classes.get(identifier)()
+            instance = all_classes.get(identifier)(**kwargs)
         else:
             handleTypeError(types=[str] + kerasy_abst_class, identifier=identifier)
             instance = identifier
